@@ -56,6 +56,11 @@ gboolean gnc_using_unreversed_budgets (QofBook* book);
  * don't match, return FALSE. */
 gboolean gnc_reverse_budget_balance (const Account *account, gboolean unreversed);
 
+/* Backward compatibility *******************************************
+ * Return that book's support opening balance accounts by equity type slot */
+void gnc_set_use_equity_type_opening_balance_account (QofBook* book);
+gboolean gnc_using_equity_type_opening_balance_account (QofBook* book);
+
 /* Default directory sections ***************************************/
 #define GNC_PREFS_GROUP_OPEN_SAVE    "dialogs.open-save"
 #define GNC_PREFS_GROUP_EXPORT       "dialogs.export-accounts"
@@ -189,28 +194,28 @@ const char * gnc_get_reconcile_str (char reconciled_flag);
 const char * gnc_get_reconcile_valid_flags (void);
 const char * gnc_get_reconcile_flag_order (void);
 
-#define WASSOC 'w'
-#define FASSOC 'f'
+#define WLINK 'w'
+#define FLINK 'f'
 
-/** Get a string containing association valid flags
+/** Get a string containing documentation link valid flags
  *
- *  @return a string containing the list of associated flags
+ *  @return a string containing the list of valid link_flags
  */
-const char *gnc_get_association_valid_flags (void);
+const char *gnc_get_doclink_valid_flags (void);
 
-/** Get a string containing association flag order
+/** Get a string containing document link flag order
  *
- * @return a string containing the association flag change order
+ * @return a string containing the document link flag change order
  */
-const char *gnc_get_association_flag_order (void);
+const char *gnc_get_doclink_flag_order (void);
 
-/** Get a string representing the association type
+/** Get a string representing the document link type
  *
- * @param  association_flag The flag to convert into a string
+ * @param  link_flag The flag to convert into a string
  *
- * @return the i18n'd association string
+ * @return the i18n'd doclink string
  */
-const char *gnc_get_association_str (char association_flag);
+const char *gnc_get_doclink_str (char link_flag);
 
 typedef enum
 {
@@ -239,9 +244,6 @@ gnc_commodity * gnc_locale_default_currency_nodefault (void);
  * "USD", but this will have nothing to do with the actual locale. */
 gnc_commodity * gnc_locale_default_currency (void);
 
-/* Returns the default ISO currency string of the current locale. */
-const char * gnc_locale_default_iso_currency_code (void);
-
 
 /** Return the default currency set by the user.  If the user's
  *  preference is invalid, then this routine will return the default
@@ -361,7 +363,7 @@ gboolean xaccParseAmount (const char * in_str, gboolean monetary,
 
 /*
  * xaccParseAmountPosSign is just like xaccParseAmount except the
- * caller can choose whether the locale's postive sign (or in absense
+ * caller can choose whether the locale's positive sign (or in absence
  * the '+') character is ignored. Setting skip to TRUE will cause
  * the function to ignore any positive sign. Setting it to FALSE,
  * and positive signs will be treated as unrecognized characters.
