@@ -21,7 +21,105 @@
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 
 
+(define-module (gnucash app-utils date-utilities))
+
+(eval-when (compile load eval expand)
+  (load-extension "libgnc-app-utils" "scm_init_sw_app_utils_module"))
+
+(use-modules (gnucash engine))
 (use-modules (gnucash core-utils))
+(use-modules (gnucash utilities))
+(use-modules (sw_app_utils))
+(use-modules (ice-9 match))
+
+(export gnc:reldate-list)
+(export gnc:date-get-year)
+(export gnc:date-get-quarter)
+(export gnc:date-get-month-day)
+(export gnc:date-get-month)
+(export gnc:date-get-week-day)
+(export gnc:date-get-week)
+(export gnc:date-get-year-day)
+(export gnc:time64-get-year)
+(export gnc:time64-get-quarter)
+(export gnc:time64-get-month-day)
+(export gnc:time64-get-month)
+(export gnc:time64-get-week-day)
+(export gnc:time64-get-week)
+(export gnc:time64-get-year-day)
+(export gnc:date-get-year-string)
+(export gnc:date-get-quarter-string)
+(export gnc:date-get-quarter-year-string)
+(export gnc:date-get-month-string)
+(export gnc:date-get-month-year-string)
+(export gnc:date-get-week-year-string)
+(export gnc:leap-year?)
+(export gnc:days-in-year)
+(export gnc:days-in-month)
+(export gnc:date-to-year-fraction)
+(export gnc:date-year-delta)
+(export gnc:date-to-month-fraction)
+(export gnc:date-to-week-fraction)
+(export gnc:date-to-week)
+(export gnc:date-to-day-fraction)
+(export gnc:date-get-fraction-func)
+(export moddatek)
+(export decdate)
+(export incdate)
+(export decdate)
+(export incdate)
+(export gnc:make-date-interval-list)
+(export gnc:make-date-list)
+(export SecDelta)
+(export DayDelta)
+(export WeekDelta)
+(export TwoWeekDelta)
+(export MonthDelta)
+(export QuarterDelta)
+(export HalfYearDelta)
+(export YearDelta)
+(export ThirtyDayDelta)
+(export NinetyDayDelta)
+(export gnc:deltasym-to-delta)
+(export gnc:time64-start-day-time)
+(export gnc:time64-end-day-time)
+(export gnc:time64-previous-day)
+(export gnc:time64-next-day)
+(export gnc:reldate-get-symbol)
+(export gnc:reldate-get-string)
+(export gnc:reldate-get-desc)
+(export gnc:reldate-get-fn)
+(export gnc:get-absolute-from-relative-date)
+(export gnc:get-relative-date-string)
+(export gnc:get-relative-date-desc)
+(export gnc:get-start-cal-year)
+(export gnc:get-end-cal-year)
+(export gnc:get-start-prev-year)
+(export gnc:get-end-prev-year)
+(export gnc:get-start-this-month)
+(export gnc:get-end-this-month)
+(export gnc:get-start-prev-month)
+(export gnc:get-end-prev-month)
+(export gnc:get-start-current-quarter)
+(export gnc:get-end-current-quarter)
+(export gnc:get-start-prev-quarter)
+(export gnc:get-end-prev-quarter)
+(export gnc:get-today)
+(export gnc:get-one-month-ago)
+(export gnc:get-three-months-ago)
+(export gnc:get-six-months-ago)
+(export gnc:get-one-year-ago)
+(export gnc:reldate-initialize)
+(export gnc:get-end-next-month)
+(export gnc:get-end-next-quarter)
+(export gnc:get-end-next-year)
+(export gnc:get-one-month-ahead)
+(export gnc:get-one-year-ahead)
+(export gnc:get-six-months-ahead)
+(export gnc:get-start-next-month)
+(export gnc:get-start-next-quarter)
+(export gnc:get-start-next-year)
+(export gnc:get-three-months-ahead)
 
 ;; get stuff from localtime date vector
 (define (gnc:date-get-year datevec)
@@ -68,7 +166,7 @@
   (gnc-print-time64 (gnc-mktime datevec) "%Y"))
 
 (define (gnc:date-get-quarter-string datevec)
-  (format #f "Q~d" (gnc:date-get-quarter datevec)))
+  (format #f "Q~a" (gnc:date-get-quarter datevec)))
 
 (define (gnc:date-get-quarter-year-string datevec)
   (string-append 
@@ -692,12 +790,13 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-three-months-ago)
+  (issue-deprecation-warning "gnc:get-three-months-ago is unused.")
   (let ((now (gnc-localtime (current-time))))
     (if (< (tm:mon now) 3)
 	(begin
-	  (set:tm-mon now (+ (tm:mon now) 12))
-	  (set:tm-year now  (- (tm:year now) 1))))
-    (set:tm-mon now (- (tm:mon now) 3))
+	  (set-tm:mon now (+ (tm:mon now) 12))
+	  (set-tm:year now  (- (tm:year now) 1))))
+    (set-tm:mon now (- (tm:mon now) 3))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -706,12 +805,13 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-six-months-ago)
+  (issue-deprecation-warning "gnc:get-six-months-ago is unused.")
   (let ((now (gnc-localtime (current-time))))
     (if (< (tm:mon now) 6)
 	(begin
-	  (set:tm-mon now (+ (tm:mon now) 12))
-	  (set:tm-year now  (- (tm:year now) 1))))
-    (set:tm-mon now (- (tm:mon now) 6))
+	  (set-tm:mon now (+ (tm:mon now) 12))
+	  (set-tm:year now  (- (tm:year now) 1))))
+    (set-tm:mon now (- (tm:mon now) 6))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -720,8 +820,9 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-one-year-ago)
+  (issue-deprecation-warning "gnc:get-one-year-ago is unused.")
   (let ((now (gnc-localtime (current-time))))
-    (set:tm-year now (- (tm:year now) 1))
+    (set-tm:year now (- (tm:year now) 1))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -744,12 +845,13 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-three-months-ahead)
+  (issue-deprecation-warning "gnc:get-three-months-ahead is unused.")
   (let ((now (gnc-localtime (current-time))))
     (if (> (tm:mon now) 8)
 	(begin
-	  (set:tm-mon now (- (tm:mon now) 9))
-	  (set:tm-year now  (+ (tm:year now) 1))
-          (set:tm-mon now (+ (tm:mon now) 3))))
+	  (set-tm:mon now (- (tm:mon now) 9))
+	  (set-tm:year now  (+ (tm:year now) 1))
+          (set-tm:mon now (+ (tm:mon now) 3))))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -758,12 +860,13 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-six-months-ahead)
+  (issue-deprecation-warning "gnc:get-six-months-ahead is unused.")
   (let ((now (gnc-localtime (current-time))))
     (if (> (tm:mon now) 5)
 	(begin
-	  (set:tm-mon now (- (tm:mon now) 6))
-	  (set:tm-year now  (+ (tm:year now) 1))
-          (set:tm-mon now (+ (tm:mon now) 6))))
+	  (set-tm:mon now (- (tm:mon now) 6))
+	  (set-tm:year now  (+ (tm:year now) 1))
+          (set-tm:mon now (+ (tm:mon now) 6))))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -772,8 +875,9 @@ Defaulting to today."))
       (gnc-mktime now))))
 
 (define (gnc:get-one-year-ahead)
+  (issue-deprecation-warning "gnc:get-one-year-ahead is unused.")
   (let ((now (gnc-localtime (current-time))))
-    (set:tm-year now (+ (tm:year now) 1))
+    (set-tm:year now (+ (tm:year now) 1))
     (let ((month-days (gnc:days-in-month (+ (tm:mon now) 1)
                                          (+ (tm:year now) 1900))))
       (if (< month-days (tm:mday now))
@@ -792,7 +896,15 @@ Defaulting to today."))
 ;;one-month-ago three-months-ago six-months-ago one-year-ago
 ;;start-cur-fin-year start-prev-fin-year end-prev-fin-year
 
-(define gnc:reldate-string-db (gnc:make-string-database))
+
+(define (make-string-database)
+  (define string-hash (make-hash-table))
+  (match-lambda*
+    (('lookup key) (G_ (hash-ref string-hash key)))
+    (('store key string) (hash-set! string-hash key string))
+    (_ (gnc:warn "string-database: bad action"))))
+
+(define gnc:reldate-string-db (make-string-database))
 (define gnc:relative-date-values #f)
 (unless gnc:relative-date-hash
   (gnc:reldate-string-db 
