@@ -206,19 +206,14 @@
 ;;          text.  stylesheets, really, should be able to remove
 ;;          link markup.
 ;; 
-;;     parent-account-subtotal-mode: #t #f 'canonically-tabbed
+;;     parent-account-subtotal-mode: #t #f
 ;; 
 ;;          indicates whether or not to add a line, recursively
 ;;          subtotalling an account and its descendents, for any
-;;          account with children (non-leaf account).  if #t or
-;;          #canonically-tabbed, a subtotal row will be created for
-;;          each non-leaf account.  if #f, no non-leaf account
-;;          subtotal rows will be created.  if 'canonically-tabbed,
-;;          account total entry labels will be placed at the position
-;;          specified by accounting texts (indented one column from
-;;          the accounts being totalled, two columns from where
-;;          gnc:html-acct-table would otherwise place them). the
-;;          default is #f.
+;;          account with children (non-leaf account).  if #t, a
+;;          subtotal row will be created for each non-leaf account.
+;;          if #f, no non-leaf account subtotal rows will be
+;;          created. the default is #f.
 ;; 
 ;;     zero-balance-mode: 'show-leaf-acct 'omit-leaf-acct
 ;; 
@@ -227,19 +222,11 @@
 ;;          account having a balance of zero. otherwise, a row will be
 ;;          generated for the account.
 ;; 
-;;     balance-mode: 'pre-adjusting 'pre-closing 'post-closing
+;;     balance-mode: 'pre-closing 'post-closing
 ;;
 ;;          indicates whether or not to ignore adjusting/closing
 ;;          entries when computing account balances. 'pre-closing
-;;          ignores only closing entries. 'pre-adjusting also ignores
-;;          adjusting entries. 'post-closing counts all entries.
-;; 
-;;     adjusting-pattern: alist of 'str 'cased 'regexp
-;; 
-;;          a pattern alist, as accepted by
-;;          gnc:account-get-trans-type-balance-interval, matching
-;;          adjusting transactions to be ignored when balance-mode is
-;;          'pre-adjusting.
+;;          ignores, 'post-closing counts closing entries.
 ;; 
 ;;     closing-pattern: alist of 'str 'cased 'regexp
 ;; 
@@ -357,18 +344,14 @@
 ;;         the number of columns in the group of account columns to
 ;;         which a row was assigned.  also one more than the maximum
 ;;         column depth at which rows were positioned in the
-;;         table. this value may be different from logical-cols when
-;;         parent-account-subtotal-mode is 'canonically-tabbed.
+;;         table.
 ;; 
 ;;     account-cols: integer
 ;; 
 ;;         the number of columns in the group of account columns.  if
 ;;         display-tree-depth is #f, this is the value of label-cols
 ;;         plus any indent.  if display-tree-depth is set, this is the
-;;         value of display-tree-depth, plus indent plus zero, if
-;;         parent-account-subotal-mode is not 'canonically-tabbed, or,
-;;         if parent-account-subtotal-mode is 'canonically-tabbed,
-;;         plus one.  don't you just love english?
+;;         value of display-tree-depth, plus indent.
 ;; 
 ;;     account-colspan: integer
 ;; 
@@ -495,8 +478,42 @@
 ;; user.  This class simply maps its contents to the html-table.
 ;; 
 
+(define-module (gnucash report html-acct-table))
+
 (use-modules (srfi srfi-2))
 (use-modules (srfi srfi-9))
+(use-modules (gnucash core-utils))
+(use-modules (gnucash engine))
+(use-modules (gnucash app-utils))
+(use-modules (gnucash report commodity-utilities))
+(use-modules (gnucash report report-utilities))
+(use-modules (gnucash report html-utilities))
+(use-modules (gnucash report html-text))
+(use-modules (gnucash report html-table))
+
+(export <html-acct-table>)
+(export gnc:html-acct-table?)
+(export gnc:_make-html-acct-table_)
+(export gnc:make-html-acct-table)
+(export gnc:make-html-acct-table/env)
+(export gnc:make-html-acct-table/env/accts)
+(export gnc:_html-acct-table-matrix_)
+(export gnc:_html-acct-table-set-matrix!_)
+(export gnc:_html-acct-table-env_)
+(export gnc:_html-acct-table-set-env!_)
+(export gnc:html-acct-table-add-accounts!)
+(export gnc:html-acct-table-num-rows)
+(export gnc:html-acct-table-get-row)
+(export gnc:html-acct-table-get-cell)
+(export gnc:html-acct-table-set-cell!)
+(export gnc:html-acct-table-get-row-env)
+(export gnc:html-acct-table-set-row-env!)
+(export gnc:account-code-less-p)
+(export gnc:account-name-less-p)
+(export gnc:account-path-less-p)
+(export gnc:html-table-add-labeled-amount-line!)
+(export gnc:html-table-add-account-balances)
+(export gnc-commodity-table)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;  <html-acct-table> class
@@ -512,6 +529,8 @@
 (define (gnc:make-html-acct-table)
   (gnc:_make-html-acct-table_ (gnc:make-html-table) #f))
 
+(define gnc:html-acct-table-set-env! gnc:_html-acct-table-set-env!_)
+
 (define (gnc:make-html-acct-table/env env)
   (let ((acct-table (gnc:make-html-acct-table)))
     (gnc:html-acct-table-set-env! acct-table env)
@@ -528,14 +547,14 @@
 
 ;; some useful predicates to export
 (define (gnc:account-code-less-p a b)
-  (string<? (xaccAccountGetCode a)
-	    (xaccAccountGetCode b)))
+  (gnc:string-locale<? (xaccAccountGetCode a)
+                       (xaccAccountGetCode b)))
 (define (gnc:account-name-less-p a b)
-  (string<? (xaccAccountGetName a)
-	    (xaccAccountGetName b)))
+  (gnc:string-locale<? (xaccAccountGetName a)
+                       (xaccAccountGetName b)))
 (define (gnc:account-path-less-p a b)
-  (string<? (gnc-account-get-full-name a)
-	    (gnc-account-get-full-name b)))
+  (gnc:string-locale<? (gnc-account-get-full-name a)
+                       (gnc-account-get-full-name b)))
 
 
 (define (gnc:html-acct-table-add-accounts! acct-table accounts)
@@ -595,11 +614,6 @@
 			       (list 'cased #f)
 			       (list 'regexp #f)
 			       (list 'closing #t))))
-	 (adjusting-pattern (or (get-val env 'adjusting-pattern)
-				(list
-				 (list 'str (G_ "Adjusting Entries"))
-				 (list 'cased #f)
-				 (list 'regexp #f))))
 	 (report-budget (or (get-val env 'report-budget) #f))
 	 ;; local variables
 	 (toplvl-accts
@@ -648,13 +662,6 @@
            (merge-splits (gnc:account-get-trans-type-splits-interval
                           accts closing-pattern start-date end-date) #t))
 
-          ;; remove closing and adjusting entries
-          ((pre-adjusting)
-           (merge-splits (gnc:account-get-trans-type-splits-interval
-                          accts closing-pattern start-date end-date) #t)
-           (merge-splits (gnc:account-get-trans-type-splits-interval
-                          accts adjusting-pattern start-date end-date) #t))
-
           (else
            (display "you fail it\n"))))
 
@@ -792,9 +799,7 @@
                              (eq? zero-mode 'omit-leaf-acct)))
               (let ((lbl-txt (gnc:make-html-text (G_ "Total") " ")))
                 (apply gnc:html-text-append! lbl-txt (gnc:html-text-body label))
-                (if (eq? subtotal-mode 'canonically-tabbed)
-                    (set! disp-depth (+ disp-depth 1))
-                    (set! disp-depth-reached (max disp-depth-reached disp-depth)))
+                (set! disp-depth-reached (max disp-depth-reached disp-depth))
                 (add-row
                  (cons* (list 'account-label lbl-txt)
                         (list 'row-type 'subtotal-row)
@@ -1069,7 +1074,6 @@
 	      amount
 	      (+ account-cols (- 0 1)
 		 (- logical-cols display-depth)
-		 (if (equal? subtotal-mode 'canonically-tabbed) 1 0)
 		 )                          ;; amount-depth
 	      1                             ;; amount-colspan
               "number-cell"                 ;; amount-markup
