@@ -19,21 +19,101 @@
 ;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+(define-module (gnucash report report-core))
+
+(eval-when (compile load eval expand)
+  (load-extension "libgnc-report" "scm_init_sw_report_module"))
 
 (use-modules (gnucash engine))
 (use-modules (gnucash utilities))
 (use-modules (gnucash app-utils))
 (use-modules (gnucash core-utils))
-(eval-when (compile load eval expand)
-  (load-extension "libgnc-report" "scm_init_sw_report_module"))
-(use-modules (sw_report))
-
+(use-modules (gnucash gnome-utils))
 (use-modules (ice-9 match))
+(use-modules (srfi srfi-1))
 (use-modules (srfi srfi-9))
+(use-modules (gnucash report report-register-hooks))
+(use-modules (gnucash report html-style-sheet))
+(use-modules (gnucash report html-document))
+(use-modules (gnucash report html-utilities))
 
-; Export the swig-wrapped symbols in the public interface of this module
-(let ((i (module-public-interface (current-module))))
-     (module-use! i (resolve-interface '(sw_report))))
+(load-and-reexport (sw_report))
+
+(export <report>)
+(export gnc:all-report-template-guids)
+(export gnc:custom-report-template-guids)
+(export gnc:define-report)
+(export gnc:delete-report)
+(export gnc:find-report-template)
+(export gnc:is-custom-report-type)
+(export gnc:make-report)
+(export gnc:make-report-options)
+(export gnc:menuname-asset-liability)
+(export gnc:menuname-budget)
+(export gnc:menuname-business-reports)
+(export gnc:menuname-custom)
+(export gnc:menuname-example)
+(export gnc:menuname-experimental)
+(export gnc:menuname-income-expense)
+(export gnc:menuname-multicolumn)
+(export gnc:menuname-reports)
+(export gnc:menuname-taxes)
+(export gnc:optname-invoice-number)
+(export gnc:optname-reportname)
+(export gnc:pagename-accounts)
+(export gnc:pagename-display)
+(export gnc:pagename-general)
+(export gnc:rename-report)
+(export gnc:report-ctext)
+(export gnc:report-dirty?)
+(export gnc:report-editor-widget)
+(export gnc:report-embedded-list)
+(export gnc:report-export-thunk)
+(export gnc:report-export-types)
+(export gnc:report-id)
+(export gnc:report-menu-name)
+(export gnc:report-name)
+(export gnc:report-needs-save?)
+(export gnc:report-options)
+(export gnc:report-render-html)
+(export gnc:render-report)
+(export gnc:report-run)
+(export gnc:report-serialize)
+(export gnc:report-set-ctext!)
+(export gnc:report-set-dirty?!)
+(export gnc:report-set-editor-widget!)
+(export gnc:report-set-id!)
+(export gnc:report-set-needs-save?!)
+(export gnc:report-set-options!)
+(export gnc:report-set-stylesheet!)
+(export gnc:report-set-type!)
+(export gnc:report-stylesheet)
+(export gnc:report-template-export-thunk)
+(export gnc:report-template-export-types)
+(export gnc:report-template-has-unique-name?)
+(export gnc:report-template-in-menu?)
+(export gnc:report-template-is-custom/template-guid?)
+(export gnc:report-template-menu-name)
+(export gnc:report-template-menu-name/report-guid)
+(export gnc:report-template-menu-path)
+(export gnc:report-template-menu-tip)
+(export gnc:report-template-name)
+(export gnc:report-template-new-options)
+(export gnc:report-template-new-options/report-guid)
+(export gnc:report-template-options-changed-cb)
+(export gnc:report-template-options-cleanup-cb)
+(export gnc:report-template-options-generator)
+(export gnc:report-template-renderer)
+(export gnc:report-template-renderer/report-guid)
+(export gnc:report-template-report-guid)
+(export gnc:report-template-set-report-guid!)
+(export gnc:report-template-version)
+(export gnc:report-templates-for-each)
+(export gnc:report-to-template-new)
+(export gnc:report-to-template-update)
+(export gnc:report-type)
+(export gnc:restore-report-by-guid)
+(export gnc:restore-report-by-guid-with-custom-template)
 
 ;; Terminology in this file:
 ;; report-template: a report definition of some form. This can be a report
@@ -155,29 +235,33 @@ not found.")))
   ;; set of options, and generates the report. the renderer must
   ;; return as its final value an <html-document> object.
   (define report-rec (make-report-template))
+  (define allowable-fields (record-type-fields <report-template>))
+  (define (not-a-field? fld) (not (memq fld allowable-fields)))
 
   (let loop ((args args))
     (match args
-      (() #f)
+      (()
+       (let ((report-guid (gnc:report-template-report-guid report-rec))
+             (report-name (gnc:report-template-name report-rec)))
+         (cond
+          ;; missing report-guid: is an error
+          ((not report-guid)
+           (gui-error (string-append rpterr-guid1 report-name rpterr-guid2)))
+
+          ;; dupe: report-guid is a duplicate
+          ((hash-ref *gnc:_report-templates_* report-guid)
+           (gui-error (string-append rpterr-dupe report-guid)))
+
+          ;; good: new report definition, store into report-templates hash
+          (else
+           (hash-set! *gnc:_report-templates_* report-guid report-rec)))))
+
+      (((? not-a-field? fld) . _)
+       (gnc:error "gnc:define-report: " fld " is not a valid field"))
+
       ((field val . rest)
        ((record-modifier <report-template> field) report-rec val)
-       (loop rest))))
-
-  (let* ((report-guid (gnc:report-template-report-guid report-rec))
-         (report-name (gnc:report-template-name report-rec)))
-    (cond
-
-     ;; missing report-guid: is an error
-     ((not report-guid)
-      (gui-error (string-append rpterr-guid1 report-name rpterr-guid2)))
-
-     ;; dupe: report-guid is a duplicate
-     ((hash-ref *gnc:_report-templates_* report-guid)
-      (gui-error (string-append rpterr-dupe report-guid)))
-
-     ;; good: new report definition, store into report-templates hash
-     (else
-      (hash-set! *gnc:_report-templates_* report-guid report-rec)))))
+       (loop rest)))))
 
 (define (gnc:report-template-new-options/report-guid template-id template-name)
   (let ((templ (hash-ref *gnc:_report-templates_* template-id)))
@@ -301,6 +385,8 @@ not found.")))
 
 
 (define (gnc:restore-report-by-guid id template-id template-name options)
+  (issue-deprecation-warning "gnc:restore-report-by-guid is now deprecated.
+ use gnc:restore-report-by-guid-with-custom-template instead.")
   (if options
       (let* ((r (make-report template-id id options #t #t #f #f ""))
              (report-id (gnc-report-add r)))
@@ -447,24 +533,12 @@ not found.")))
     (gnc:report-template-name
      (hash-ref *gnc:_report-templates_* (gnc:report-type report))))
    (gnc:generate-restore-forms (gnc:report-options report) "options")
-   ;; 2.6->2.4 compatibility code prefix
-   ;; Temporary check to make the new report saving code more or less backwards
-   ;; compatible with older gnucash versions. This can be removed again in 2.8.
-   "(if (defined? 'gnc:restore-report-by-guid-with-custom-template)\n"
-   ;; end of 2.6->2.4 compatibility code prefix.
    (format
     #f "  (gnc:restore-report-by-guid-with-custom-template ~S ~S ~S ~S options)\n"
     (gnc:report-id report) (gnc:report-type report)
     (gnc:report-template-name
      (hash-ref *gnc:_report-templates_* (gnc:report-type report)))
     (gnc:report-custom-template report))
-   ;; 2.6->2.4 compatibility code suffix
-   (format
-    #f "  (gnc:restore-report-by-guid ~S ~S ~S options))\n"
-    (gnc:report-id report) (gnc:report-type report)
-    (gnc:report-template-name
-     (hash-ref *gnc:_report-templates_* (gnc:report-type report))))
-   ;; end of 2.6->2.4 compatibility code suffix.
    ")"))
 
 ;; Generate guile code required to recreate embedded report instances
@@ -680,9 +754,17 @@ not found.")))
                (gnc:report-set-dirty?! report #f)  ;; mark it clean
                html)))))
 
+;; render report. will return a 2-element list: either (list html #f)
+;; where html is the report html string, or (list #f captured-error)
+;; where captured-error is the error string.
+(define (gnc:render-report report)
+  (define (get-report) (gnc:report-render-html report #t))
+  (gnc:apply-with-error-handling get-report '()))
+
 ;; looks up the report by id and renders it with gnc:report-render-html
 ;; marks the cursor busy during rendering; returns the html
 (define (gnc:report-run id)
+  (issue-deprecation-warning "gnc:report-run is deprecated. use gnc:render-report instead.")
   (let ((report (gnc-report-find id))
         (html #f))
     (gnc-set-busy-cursor '() #t)
@@ -725,31 +807,37 @@ not found.")))
       (gnc:report-template-set-name templ new-name)
       (gnc:save-all-reports))))
 
+;;
+;; gnucash-cli helper and exported functions
+;;
+
 (define (stderr-log tmpl . args)
   (apply format (current-error-port) tmpl args)
   #f)
 
-(define (template-export report template export-type output-file dry-run?)
+(define (template-export report template export-type dry-run?)
   (let* ((report-guid (gnc:report-template-report-guid template))
          (parent-template-guid (gnc:report-template-parent-type template))
-         (parent-template (hash-ref *gnc:_report-templates_* parent-template-guid))
-         (parent-export-thunk (gnc:report-template-export-thunk parent-template))
-         (parent-export-types (gnc:report-template-export-types parent-template)))
+         (template (if parent-template-guid
+                       (hash-ref *gnc:_report-templates_* parent-template-guid)
+                       template))
+         (export-thunk (gnc:report-template-export-thunk template))
+         (export-types (gnc:report-template-export-types template)))
 
     (cond
-     ((not parent-export-thunk) (stderr-log "Report ~s has no export code\n" report))
-     ((not parent-export-types) (stderr-log "Report ~s has no export-types\n" report))
-     ((not (assoc export-type parent-export-types))
+     ((not export-thunk) (stderr-log "Report ~s has no export code\n" report))
+     ((not export-types) (stderr-log "Report ~s has no export-types\n" report))
+     ((not (assoc export-type export-types))
       (stderr-log "Export-type disallowed: ~a. Allowed types: ~a\n"
-                  export-type (string-join (map car parent-export-types) ", ")))
-     ((not output-file) (stderr-log "No output file specified\n"))
+                  export-type (string-join (map car export-types) ", ")))
      (dry-run? #t)
      (else
       (display "Running export..." (current-error-port))
-      (parent-export-thunk
-       (gnc-report-find (gnc:make-report report-guid))
-       (assoc-ref parent-export-types export-type) output-file)
-      (display "done!\n" (current-error-port))))))
+      (let ((output (export-thunk
+                     (gnc-report-find (gnc:make-report report-guid))
+                     (assoc-ref export-types export-type))))
+        (display "done!\n" (current-error-port))
+        output)))))
 
 (define (reportname->templates report)
   (or (and=> (gnc:find-report-template report) list)
@@ -767,7 +855,8 @@ not found.")))
           (lambda (k v p) (if (gnc:report-template-in-menu? v) (cons v p) p))
           '() *gnc:_report-templates_*)
          (lambda (a b)
-           (string<? (gnc:report-template-name a) (gnc:report-template-name b))))))
+           (gnc:string-locale<? (gnc:report-template-name a)
+                                (gnc:report-template-name b))))))
 
 (define-public (gnc:cmdline-report-show report port)
   (let ((templates (reportname->templates report)))
@@ -797,16 +886,11 @@ not found.")))
                    (gnc:html-render-options-changed (options-gen) #t))))
        templates)))))
 
-(define-public (gnc:cmdline-run-report report export-type output-file dry-run?)
+;; In: report - string matching reportname
+;; In: export-type - string matching export type (eg CSV TXF etc)
+;; Out: if args are valid and runs a single report: #t, otherwise: #f
+(define-public (gnc:cmdline-check-report report export-type)
   (let ((templates (reportname->templates report)))
-
-    (define (run-report output-port)
-      (display
-       (gnc:report-render-html
-        (gnc-report-find
-         (gnc:make-report
-          (gnc:report-template-report-guid (car templates)))) #t) output-port))
-
     (cond
      ((null? templates)
       (stderr-log "Cannot find ~s. Valid reports:\n" report)
@@ -819,11 +903,20 @@ not found.")))
       (stderr-log "\n"))
 
      (export-type (template-export report (car templates)
-                                   export-type output-file dry-run?))
-     (dry-run? #t)
-     (output-file
-      (format (current-error-port) "Saving report to ~a..." output-file)
-      (call-with-output-file output-file run-report)
-      (display "complete!\n" (current-error-port)))
-     (else
-      (run-report (current-output-port))))))
+                                   export-type #t))
+     (else #t))))
+
+;; In: report - string matching reportname
+;; In: export-type - string matching export type (eg CSV TXF etc)
+;; Out: if error, #f
+(define-public (gnc:cmdline-template-export report export-type)
+  (match (reportname->templates report)
+    ((template) (template-export report template export-type #f))
+    (_ (gnc:error report " does not match unique report") #f)))
+
+;; In: report - string matching reportname
+;; Out: a number, or #f if error
+(define-public (gnc:cmdline-get-report-id report)
+  (match (reportname->templates report)
+    ((template) (gnc:make-report (gnc:report-template-report-guid template)))
+    (_ (gnc:error report " does not match unique report") #f)))
