@@ -297,7 +297,7 @@
          (show-rates? (get-option pagename-commodities optname-show-rates))
          (parent-mode (get-option gnc:pagename-display optname-parent-balance-mode))
          (parent-total-mode
-          (assq-ref '((t . #t) (f . #f) (canonically-tabbed . canonically-tabbed))
+          (assq-ref '((t . #t) (f . #f))
                     (get-option gnc:pagename-display optname-parent-total-mode)))
          (show-zb-accts? (get-option gnc:pagename-display optname-show-zb-accts))
          (omit-zb-bals? (get-option gnc:pagename-display optname-omit-zb-bals))
@@ -315,6 +315,7 @@
                          (gnc:get-current-account-tree-depth)
                          depth-limit))
          ;; exchange rates calculation parameters
+         (price-fn (gnc:case-price-fn price-source report-commodity to-date))
          (exchange-fn (gnc:case-exchange-fn price-source report-commodity to-date)))
 
     (gnc:html-document-set-title!
@@ -403,7 +404,8 @@
            build-table
            (map make-header
                 (append
-                 (if show-code? (list (G_ "Code")) '())
+                 ;; Note: If this is to long, do not use "Code" it is currently used for tax code.
+                 (if show-code? (list (G_ "Account Code")) '())
                  (if show-type? (list (G_ "Type")) '())
                  (if show-desc? (list (G_ "Description")) '())
                  (list (G_ "Account title")))))
@@ -441,8 +443,8 @@
           ;; add currency information
           (when show-rates?
             (gnc:html-document-add-object!
-             doc (gnc:html-make-exchangerates
-                  report-commodity exchange-fn
+             doc (gnc:html-make-rates-table
+                  report-commodity price-fn
                   (gnc:accounts-and-all-descendants accounts))))))
 
     (gnc:report-finished)
