@@ -82,8 +82,11 @@ accounts may be tagged with *EUGOODS* in the account description."))
      #:custom-calculated-cells gst-calculated-cells
      #:custom-source-accounts sales-purch-accounts
      #:custom-split-filter gst-custom-split-filter
-     #:export-type export-type
-     #:filename file-name))
+     #:export-type export-type))
+  (when file-name
+    (issue-deprecation-warning "gst-statement-renderer filename is \
+obsolete, and not supported for exports. please set html-document \
+export-string instead. this warning will be removed in GnuCash 5.0"))
   (when (null? (opt-val "Accounts" "Tax Accounts"))
     (gnc:html-document-add-object! document TAX-SETUP-DESC))
   document)
@@ -158,12 +161,12 @@ for taxes paid on expenses, and type LIABILITY for taxes collected on sales.")
     pagename-format (N_ "Report format")
     "a" (G_ "Report Format") 'default
     (list (vector 'default
-                  (G_ "default format")
-                  (G_ "default format"))
+                  (G_ "Default Format")
+                  (G_ "Default Format"))
           (vector 'au-bas
                   (G_ "Australia BAS")
-                  (G_ "Australia BAS. Specify sales, purchase and tax \
-accounts."))
+                  (G_ "Australia Business Activity Statement. Specify sales, \
+purchase and tax accounts."))
           (vector 'uk-vat
                   (G_ "UK VAT Return")
                   (G_ "UK VAT Return. Specify sales, purchase and tax \
@@ -192,14 +195,14 @@ with *EUGOODS* in the account description."))) #f
   ;; Disable account filtering
   (gnc:option-make-internal! options gnc:pagename-accounts "Filter Type")
   (gnc:option-make-internal! options gnc:pagename-accounts "Filter By...")
-  (gnc:option-make-internal! options gnc:pagename-general "Show original currency amount")
+  (gnc:option-make-internal! options "Currency" "Show original currency amount")
 
   ;; Enforce compulsory common-currency. It's senseless to allow
   ;; multiple currencies in a government report. Plus, single currency
   ;; means only 1 amount per heading for CSV output.
   (gnc:option-set-default-value
-   (gnc:lookup-option options gnc:pagename-general "Common Currency") #t)
-  (gnc:option-make-internal! options gnc:pagename-general "Common Currency")
+   (gnc:lookup-option options "Currency" "Common Currency") #t)
+  (gnc:option-make-internal! options "Currency" "Common Currency")
 
   ;; Set default dates to report on last quarter.
   (gnc:option-set-default-value
@@ -225,9 +228,6 @@ with *EUGOODS* in the account description."))) #f
   (gnc:option-set-default-value
    (gnc:lookup-option options pagename-sorting "Secondary Key")
    'none)
-  (gnc:option-set-default-value
-   (gnc:lookup-option options pagename-sorting "Secondary Subtotal")
-   'none)
 
   ;; Disable display options not being used anymore
   (gnc:option-make-internal! options gnc:pagename-display "Shares")
@@ -260,7 +260,7 @@ with *EUGOODS* in the account description."))) #f
          (accounts-tax-paid      (accfilter tax-accounts ACCT-TYPE-ASSET))
          (accounts-sales         (opt-val gnc:pagename-accounts "Sales"))
          (accounts-purchases     (opt-val gnc:pagename-accounts "Purchases"))
-         (common-currency        (opt-val gnc:pagename-general "Report's currency")))
+         (common-currency        (opt-val "Currency" "Report's currency")))
 
     (define (split-adder split accountlist)
       (define txn (xaccSplitGetParent split))
