@@ -70,7 +70,8 @@ exist but have no suitable transactions."))
 
 (define (setup-query query accounts date)
   (qof-query-set-book query (gnc-get-current-book))
-  (gnc:query-set-match-non-voids-only! query (gnc-get-current-book))
+  (xaccQueryAddClearedMatch
+   query (logand CLEARED-ALL (lognot CLEARED-VOIDED)) QOF-QUERY-AND)
   (xaccQueryAddAccountMatch query accounts QOF-GUID-MATCH-ANY QOF-QUERY-AND)
   (xaccQueryAddDateMatchTT query #f 0 #t date QOF-QUERY-AND)
   (qof-query-set-sort-order query (list SPLIT-TRANS TRANS-DATE-POSTED) '() '())
@@ -107,8 +108,8 @@ exist but have no suitable transactions."))
      (gnc:make-multichoice-option
       gnc:pagename-general optname-sort-order "ia" (N_ "Sort order.") 'increasing
       (list
-       (vector 'increasing (N_ "Increasing") (N_ "Alphabetical order"))
-       (vector 'decreasing (N_ "Decreasing") (N_ "Reverse alphabetical order")))))
+       (vector 'increasing (N_ "Ascending") (N_ "Alphabetical order"))
+       (vector 'decreasing (N_ "Descending") (N_ "Reverse alphabetical order")))))
 
     (add-option
      (gnc:make-simple-boolean-option
@@ -160,7 +161,7 @@ exist but have no suitable transactions."))
                     (gncAddressGetPhone addr)
                     (gncAddressGetFax addr)
                     (gncAddressGetEmail addr)
-                    (if (gncOwnerGetActive owner) (G_ "Y") (G_ "N")))))
+                    (if (gncOwnerGetActive owner) (C_ "One-letter indication for 'yes'" "Y") (C_ "One-letter indication for 'no'" "N")))))
            (else address-list-names))))
     (fold-right (lambda (opt elt prev) (if opt (cons elt prev) prev))
                 '() address-list-options result-list)))
@@ -217,7 +218,7 @@ exist but have no suitable transactions."))
       (match-let* (((own1 aging1 aging-total1) a)
                    ((own2 aging2 aging-total2) b)
                    (increasing? (eq? sort-order 'increasing))
-                   (op-str (if increasing? string<? string>?))
+                   (op-str (if increasing? gnc:string-locale<? gnc:string-locale>?))
                    (op-num (if increasing? < >)))
         (case sort-by
           ((name)  (op-str (gncOwnerGetName own1) (gncOwnerGetName own2)))
@@ -230,7 +231,9 @@ exist but have no suitable transactions."))
               (else (op-num (car aging1) (car aging2)))))))))
 
     ;; set default title
-    (gnc:html-document-set-title! document report-title)
+    (gnc:html-document-set-title!
+     document
+     (format #f "~a - ~a" report-title (qof-print-date report-date)))
 
     (cond
      ((null? accounts)
@@ -309,7 +312,7 @@ exist but have no suitable transactions."))
                               "number-cell"
                               (gnc:make-html-text
                                (gnc:html-markup-anchor
-                                (gnc:owner-report-text owner account)
+                                (gnc:owner-report-text owner account report-date)
                                 (gnc:make-gnc-monetary comm aging-total)))))
                             (options->address options receivable owner)))))
                       (sort owners-and-aging sort-aging<?))
