@@ -29,6 +29,7 @@
 (define-module (gnucash reports standard new-owner-report))
 
 (use-modules (srfi srfi-1))
+(use-modules (srfi srfi-2))
 (use-modules (srfi srfi-8))
 (use-modules (srfi srfi-9))
 (use-modules (srfi srfi-11))             ;for let-values
@@ -55,7 +56,8 @@
 (define credit-header (N_ "Credits"))
 (define debit-header (N_ "Debits"))
 (define balance-header (N_ "Balance"))
-(define linked-txns-header (N_ "Links"))
+(define doclink-header (N_ "Document Links"))
+(define linked-txns-header (N_ "Transaction Links"))
 
 (define javascript "
 <script>
@@ -161,6 +163,8 @@
   (vector-ref columns-used 8))
 (define (bal-col columns-used)
   (vector-ref columns-used 9))
+(define (doclink-col columns-used)
+  (vector-ref columns-used 10))
 
 (define (num-cols columns-used section)
   (let* ((date? (date-col columns-used))
@@ -173,12 +177,14 @@
          (credit? (credit-col columns-used))
          (debit? (debit-col columns-used))
          (bal? (bal-col columns-used))
+         (doclink? (doclink-col columns-used))
          (spacer? (or date? type? ref? desc? debit? credit?))
          (amt? (or credit? debit?))
          (cols-alist
           (list
-           (list 'lhs-cols date? due? ref? type? desc? sale? tax? credit? debit? bal?)
-           (list 'ptt-span date? due? ref? type? desc?)
+           (list 'lhs-cols date? due? ref? type? desc? sale? tax? credit? debit? bal?
+                 doclink?)
+           (list 'ptt-span date? due? ref? type? desc? doclink?)
            (list 'mid-spac spacer?)
            (list 'rhs-cols date? ref? type? desc? amt? amt?)
            (list 'rhs-span date? ref? type? desc?)))
@@ -193,7 +199,7 @@
    (map opt-val
         (list date-header due-date-header reference-header type-header
               desc-header sale-header tax-header debit-header credit-header
-              balance-header))))
+              balance-header doclink-header))))
 
 (define (make-heading-list column-vector link-option acct-type)
   (let ((heading-list '())
@@ -209,16 +215,22 @@
         (addto! heading-list (G_ type-header)))
     (if (desc-col column-vector)
         (addto! heading-list (G_ desc-header)))
+    (if (doclink-col column-vector)
+        (addto! heading-list (C_ "Column header for 'Document Link'" "L")))
     (if (sale-col column-vector)
         (addto! heading-list (G_ sale-header)))
     (if (tax-col column-vector)
         (addto! heading-list (G_ tax-header)))
     (if (debit-col column-vector)
         (addto! heading-list
-                (if formal? debit-header (gnc-account-get-debit-string acct-type))))
+                (if formal?
+                    (G_ debit-header)
+                    (gnc-account-get-debit-string acct-type))))
     (if (credit-col column-vector)
         (addto! heading-list
-                (if formal? credit-header (gnc-account-get-credit-string acct-type))))
+                (if formal?
+                    (G_ credit-header)
+                    (gnc-account-get-credit-string acct-type))))
     (if (bal-col column-vector)
         (addto! heading-list (G_ balance-header)))
     (case link-option
@@ -289,14 +301,16 @@
 
 ;; input: list of html-text elements
 ;; output: a cell with html-text interleaved with <br> tags
-(define (list->cell lst)
+(define* (list->cell lst #:optional skip-empty?)
   (let lp ((lst lst) (result '()))
     (match lst
       (() (apply gnc:make-html-text result))
+      (("" . rest) (=> fail) (if skip-empty? (lp rest result) (fail)))
       ((elt . rest) (lp rest (cons* elt (gnc:html-markup-br) result))))))
 
-(define (splits->desc splits)
-  (list->cell (map (compose gnc:html-string-sanitize xaccSplitGetMemo) splits)))
+(define* (splits->desc splits #:optional skip-empty?)
+  (list->cell (map (compose gnc:html-string-sanitize xaccSplitGetMemo) splits)
+              skip-empty?))
 
 (define (make-aging-table splits to-date payable? date-type currency)
   (let ((table (gnc:make-html-table))
@@ -339,7 +353,7 @@
 ;; Make a row list based on the visible columns
 ;;
 (define (add-row table odd-row? column-vector date due-date ref type-str
-                 desc currency amt debit credit sale tax lhs-class
+                 desc doclink-invoice currency amt debit credit sale tax lhs-class
                  link-option link-rows)
   (define nrows (if link-rows (length link-rows) 1))
   (define (link-data->cols link-data)
@@ -430,7 +444,12 @@
                      (and due-date (qof-print-date due-date)))
               (addif (ref-col column-vector)    ref)
               (addif (type-col column-vector)   type-str)
-              (addif (desc-col column-vector)   desc)))
+              (addif (desc-col column-vector)   desc)
+              (addif (doclink-col column-vector)
+                     (and doclink-invoice
+                          (gnc:html-invoice-doclink-anchor
+                           doclink-invoice
+                           (C_ "Column header for 'Document Link'" "L"))))))
             (map
              (lambda (str)
                (let ((cell (gnc:make-html-table-cell/size/markup
@@ -474,7 +493,7 @@
       ((if negate? - +)
        (AP-negate (xaccSplitGetAmount split))))))
 
-  (define (print-totals total debit credit tax sale)
+  (define (print-totals total debit credit tax sale invalid-splits)
     (define (total-cell cell)
       (gnc:make-html-table-cell/markup "total-number-cell" cell))
     (define (make-cell amt)
@@ -518,6 +537,20 @@
           (addif (< 0 rhs-cols)
                  (gnc:make-html-table-cell/size 1 (+ mid-span rhs-cols) #f)))))
 
+    (unless (null? invalid-splits)
+      (gnc:html-table-append-row/markup!
+       table "grand-total"
+       (list (gnc:make-html-table-cell/size
+              1 (+ grand-span mid-span rhs-cols)
+              (gnc:make-html-text
+               (G_ "Please note some transactions were not processed")
+               (gnc:html-markup-ol
+                (map
+                 (match-lambda
+                   ((split txt)
+                    (gnc:html-markup-anchor (gnc:split-anchor-text split) txt)))
+                 invalid-splits)))))))
+
     ;; print aging table
     (gnc:html-table-append-row/markup!
      table "grand-total"
@@ -528,7 +561,7 @@
                               payable? date-type currency)))))
 
   (define (add-balance-row odd-row? total)
-    (add-row table odd-row? used-columns start-date #f "" (G_ "Balance") ""
+    (add-row table odd-row? used-columns start-date #f "" (G_ "Balance") "" #f
              currency total #f #f #f #f #f
              link-option (case link-option
                            ((none) '(()))
@@ -708,9 +741,12 @@
       (gnc:split-anchor-text split)
       (gnc:make-gnc-monetary currency amount))))
 
+  (define seen-txns (make-hash-table))
+
   (let lp ((printed? #f)
            (odd-row? #t)
            (splits splits)
+           (invalid-splits '())
            (total 0)
            (debit 0)
            (credit 0)
@@ -724,7 +760,7 @@
       ;;start-date (and no other rows would be added either) so add it now
       (when (and (not printed?) (bal-col used-columns) (not (zero? total)))
         (add-balance-row odd-row? total))
-      (print-totals total debit credit tax sale)
+      (print-totals total debit credit tax sale invalid-splits)
       (gnc:html-table-set-style!
        table "table"
        'attribute (list "border" 1)
@@ -732,10 +768,13 @@
        'attribute (list "cellpadding" 4))
       table)
 
+     ((hash-ref seen-txns (xaccSplitGetParent (car splits)))
+      (lp printed? odd-row? (cdr splits) invalid-splits total debit credit tax sale))
+
      ;; not an invoice/payment. skip transaction.
      ((not (or (txn-is-invoice? (xaccSplitGetParent (car splits)))
                (txn-is-payment? (xaccSplitGetParent (car splits)))))
-      (lp printed? odd-row? (cdr splits) total debit credit tax sale))
+      (lp printed? odd-row? (cdr splits) invalid-splits total debit credit tax sale))
 
      ;; invalid case: txn-type-invoice but no associated invoice, nor lot
      ((let* ((txn (xaccSplitGetParent (car splits)))
@@ -743,14 +782,18 @@
         (and (txn-is-invoice? txn)
              (or (null? invoice)
                  (null? (gncInvoiceGetPostedLot invoice)))))
-      (gnc:warn "sanity check fail" txn)
-      (lp printed? odd-row? (cdr splits) total debit credit tax sale))
+      (gnc:warn "sanity check fail " (gnc:strify (car splits)))
+      (lp printed? odd-row? (cdr splits)
+          (cons (list (car splits) "Transaction has type invoice but no owner or lot")
+                invalid-splits)
+          total debit credit tax sale))
 
      ;; txn-date < start-date. skip display, accumulate amounts
      ((< (xaccTransGetDate (xaccSplitGetParent (car splits))) start-date)
       (let* ((txn (xaccSplitGetParent (car splits)))
              (value (AP-negate (xaccTransGetAccountAmount txn acc))))
-        (lp printed? odd-row? (cdr splits) (+ total value)
+        (hash-set! seen-txns txn #t)
+        (lp printed? odd-row? (cdr splits) invalid-splits (+ total value)
             debit credit tax sale)))
 
      ;; if balance row hasn't been rendered, consider
@@ -758,10 +801,11 @@
      ((not printed?)
       (let ((print? (and (bal-col used-columns) (not (zero? total)))))
         (if print? (add-balance-row odd-row? total))
-        (lp #t (not print?) splits total debit credit tax sale)))
+        (lp #t (not print?) splits invalid-splits total debit credit tax sale)))
 
      ;; start printing txns.
      ((txn-is-invoice? (xaccSplitGetParent (car splits)))
+      (hash-set! seen-txns (xaccSplitGetParent (car splits)) #t)
       (let* ((split (car splits))
              (txn (xaccSplitGetParent split))
              (date (xaccTransGetDate txn))
@@ -777,6 +821,7 @@
          (split->reference split)
          (split->type-str split payable?)
          (splits->desc (list split))
+         (and (not (string-null? (gncInvoiceGetDocLink invoice))) invoice)
          currency (+ total value)
          (and (>= orig-value 0) (amount->anchor split orig-value))
          (and (< orig-value 0) (amount->anchor split (- orig-value)))
@@ -788,13 +833,14 @@
            ((detailed) (make-invoice->payments-table invoice))
            (else '(()))))
 
-        (lp printed? (not odd-row?) (cdr splits) (+ total value)
+        (lp printed? (not odd-row?) (cdr splits) invalid-splits (+ total value)
             (if (< 0 orig-value) (+ debit orig-value) debit)
             (if (< 0 orig-value) credit (- credit orig-value))
             (+ tax (CN-negate gncInvoiceGetTotalTax))
             (+ sale (CN-negate gncInvoiceGetTotalSubtotal)))))
 
      ((txn-is-payment? (xaccSplitGetParent (car splits)))
+      (hash-set! seen-txns (xaccSplitGetParent (car splits)) #t)
       (let* ((split (car splits))
              (txn (xaccSplitGetParent split))
              (date (xaccTransGetDate txn))
@@ -805,8 +851,8 @@
          table odd-row? used-columns date #f
          (split->reference split)
          (split->type-str split payable?)
-         (splits->desc (xaccTransGetAPARAcctSplitList txn #t))
-         currency (+ total value)
+         (splits->desc (xaccTransGetAPARAcctSplitList txn #t) #t)
+         #f currency (+ total value)
          (and (>= orig-value 0) (amount->anchor split orig-value))
          (and (< orig-value 0) (amount->anchor split (- orig-value)))
          #f #f
@@ -817,7 +863,7 @@
            ((detailed) (make-payment->payee-table txn))
            (else '(()))))
 
-        (lp printed? (not odd-row?) (cdr splits) (+ total value)
+        (lp printed? (not odd-row?) (cdr splits) invalid-splits (+ total value)
             (if (< 0 orig-value) (+ debit orig-value) debit)
             (if (< 0 orig-value) credit (- credit orig-value))
             tax
@@ -910,6 +956,11 @@
                   (N_ "Invoices show list of payments, payments show list of \
 invoices and amounts.")))))
 
+  (gnc:register-inv-option
+   (gnc:make-simple-boolean-option
+    (N_ "Display Columns") doclink-header
+    "hd" (N_ "Display document link?") #f))
+
   (gnc:register-inv-option
    (gnc:make-multichoice-option
     gnc:pagename-general optname-date-driver "k"
@@ -991,10 +1042,7 @@ invoices and amounts.")))))
     (gnc:option-value
      (gnc:lookup-option options section name)))
 
-  (let* ((accounts (filter (compose xaccAccountIsAPARType xaccAccountGetType)
-                           (gnc-account-get-descendants-sorted
-                            (gnc-get-current-root-account))))
-         (start-date (gnc:time64-start-day-time
+  (let* ((start-date (gnc:time64-start-day-time
                       (gnc:date-option-absolute-time
                        (opt-val gnc:pagename-general optname-from-date))))
          (end-date (gnc:time64-end-day-time
@@ -1009,18 +1057,18 @@ invoices and amounts.")))))
          (owner-descr (owner-string type))
          (date-type (opt-val gnc:pagename-general optname-date-driver))
          (owner (opt-val owner-page owner-descr))
-         (payable? (memv (gncOwnerGetType (gncOwnerGetEndOwner owner))
-                         (list GNC-OWNER-VENDOR GNC-OWNER-EMPLOYEE)))
+         (acct-type (if (eqv? (gncOwnerGetType (gncOwnerGetEndOwner owner))
+                              GNC-OWNER-CUSTOMER)
+                        ACCT-TYPE-RECEIVABLE ACCT-TYPE-PAYABLE))
+         (accounts (filter (lambda (a) (eqv? (xaccAccountGetType a) acct-type))
+                           (gnc-account-get-descendants-sorted
+                            (gnc-get-current-root-account))))
+         (payable? (eqv? ACCT-TYPE-PAYABLE acct-type))
          (query (qof-query-create-for-splits))
          (document (gnc:make-html-document))
          (table (gnc:make-html-table))
          (section-headings (make-section-heading-list used-columns owner-descr))
-         (headings (make-heading-list
-                    used-columns link-option
-                    (if (eqv? (gncOwnerGetType (gncOwnerGetEndOwner owner))
-                              GNC-OWNER-CUSTOMER)
-                        ACCT-TYPE-RECEIVABLE
-                        ACCT-TYPE-PAYABLE)))
+         (headings (make-heading-list used-columns link-option acct-type))
          (report-title (string-append (G_ owner-descr) " " (G_ "Report"))))
 
     (cond
@@ -1042,7 +1090,7 @@ invoices and amounts.")))))
      (else
       (setup-query query owner accounts end-date (eqv? GNC-OWNER-JOB type))
 
-      (let ((splits (xaccQueryGetSplitsUniqueTrans query)))
+      (let ((splits (qof-query-run query)))
         (qof-query-destroy query)
 
         (gnc:html-document-set-headline!
@@ -1060,10 +1108,8 @@ invoices and amounts.")))))
           (gnc:html-document-add-object!
            document
            (gnc:make-html-text
-            (gnc:html-markup-h2 (G_ "No transactions found."))
-            (gnc:html-markup-p
-             (format #f (G_ "No transactions were found associated with the ~a.")
-                     (string-downcase (car (get-info type)))))
+            (gnc:html-markup-h3 (G_ "No transactions found."))
+            (gnc:html-markup-p (G_ "No matching transactions found"))
             (gnc:html-make-options-link (gnc:report-id report-obj)))))
 
          (else
@@ -1193,28 +1239,28 @@ invoices and amounts.")))))
  'in-menu? #t)
 
 
-(define (owner-report-create-internal report-guid owner owner-type)
+(define (owner-report-create-internal report-guid owner owner-type enddate)
   (let* ((options (gnc:make-report-options report-guid))
-         (owner-op (gnc:lookup-option options owner-page (owner-string owner-type))))
+         (owner-op (gnc:lookup-option options owner-page (owner-string owner-type)))
+         (date-op (gnc:lookup-option options gnc:pagename-general optname-to-date)))
 
     (gnc:option-set-value owner-op owner)
+    (when enddate
+      (gnc:option-set-value date-op (cons 'absolute enddate)))
     (gnc:make-report report-guid options)))
 
-(define (owner-report-create owner account)
+(define (owner-report-create-with-enddate owner account enddate)
   ;; note account isn't actually used
-  (let ((type (gncOwnerGetType (gncOwnerGetEndOwner owner))))
-    (cond
-     ((eqv? type GNC-OWNER-CUSTOMER)
-      ;; Not sure whether to pass type, or to use the guid in the report function
-      (owner-report-create-internal customer-report-guid owner type))
+  (define guid-alist
+    (list (cons GNC-OWNER-CUSTOMER customer-report-guid)
+          (cons GNC-OWNER-VENDOR vendor-report-guid)
+          (cons GNC-OWNER-EMPLOYEE employee-report-guid)))
+  (and-let* ((type (gncOwnerGetType (gncOwnerGetEndOwner owner)))
+             (guid (assv-ref guid-alist type)))
+    (owner-report-create-internal guid owner type enddate)))
 
-     ((eqv? type GNC-OWNER-VENDOR)
-      (owner-report-create-internal vendor-report-guid owner type))
-
-     ((eqv? type GNC-OWNER-EMPLOYEE)
-      (owner-report-create-internal employee-report-guid owner type))
-
-     (else #f))))
+(define (owner-report-create owner account)
+  (owner-report-create-with-enddate owner account #f))
 
 (define (gnc:owner-report-create-internal
          account split query journal? double? title debit-string credit-string)
@@ -1229,3 +1275,4 @@ invoices and amounts.")))))
 (gnc:register-report-hook ACCT-TYPE-RECEIVABLE #t gnc:owner-report-create-internal)
 (gnc:register-report-hook ACCT-TYPE-PAYABLE #t gnc:owner-report-create-internal)
 (export owner-report-create)
+(export owner-report-create-with-enddate)
